.. semantic-link-labs documentation master file, created by
   sphinx-quickstart on Thu Jun  6 15:52:49 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to semantic-link-labs's documentation!
==============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
